@@ -2,7 +2,7 @@
 
 from .core import Actuator
 from .component import Link, Joint
-from .solver import FKSolver, IKSolver
+from .solver import FKSolver, IKSolver, CCDFKSolver, CCDIKSolver
 from .optimizer import (
     NewtonOptimizer, SteepestDescentOptimizer, ConjugateGradientOptimizer,
     ScipyOptimizer, ScipySmoothOptimizer
@@ -13,7 +13,7 @@ from .visualizer import visualize
 __all__ = (
     'Actuator',
     'Link', 'Joint',
-    'FKSolver', 'IKSolver',
+    'FKSolver', 'IKSolver', 'CCDFKSolver', 'CCDIKSolver',
     'NewtonOptimizer', 'SteepestDescentOptimizer',
     'ConjugateGradientOptimizer',
     'ScipyOptimizer', 'ScipySmoothOptimizer',
